# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AttestationRecord(BaseModel):
    """
    AttestationRecord
    """ # noqa: E501
    id: StrictStr = Field(description="The ID of the attestation record.")
    created_at: datetime = Field(description="Time of record creation.")
    policy_attestation_rule_id: StrictStr = Field(description="The ID of the attestation rule.")
    policy_model_assignment_id: StrictStr = Field(description="The ID of the policy assignment.")
    model_id: StrictStr = Field(description="The ID of the model.")
    attested_by_user_id: Optional[StrictStr] = None
    notes: Optional[StrictStr] = None
    attested_at: datetime = Field(description="When the attestation was submitted.")
    next_attestation_due: datetime = Field(description="When the next attestation is due.")
    __properties: ClassVar[List[str]] = ["id", "created_at", "policy_attestation_rule_id", "policy_model_assignment_id", "model_id", "attested_by_user_id", "notes", "attested_at", "next_attestation_due"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AttestationRecord from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if attested_by_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.attested_by_user_id is None and "attested_by_user_id" in self.model_fields_set:
            _dict['attested_by_user_id'] = None

        # set to None if notes (nullable) is None
        # and model_fields_set contains the field
        if self.notes is None and "notes" in self.model_fields_set:
            _dict['notes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AttestationRecord from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "created_at": obj.get("created_at"),
            "policy_attestation_rule_id": obj.get("policy_attestation_rule_id"),
            "policy_model_assignment_id": obj.get("policy_model_assignment_id"),
            "model_id": obj.get("model_id"),
            "attested_by_user_id": obj.get("attested_by_user_id"),
            "notes": obj.get("notes"),
            "attested_at": obj.get("attested_at"),
            "next_attestation_due": obj.get("next_attestation_due")
        })
        return _obj


