# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.sensitive_data_plane import SensitiveDataPlane

class TestSensitiveDataPlane(unittest.TestCase):
    """SensitiveDataPlane unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SensitiveDataPlane:
        """Test SensitiveDataPlane
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SensitiveDataPlane`
        """
        model = SensitiveDataPlane()
        if include_optional:
            return SensitiveDataPlane(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                workspace_id = '',
                description = '',
                user_id = '',
                infrastructure = 'AWS',
                last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                    gen_ai_enabled = True, ),
                client_id = '',
                client_secret = ''
            )
        else:
            return SensitiveDataPlane(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                workspace_id = '',
                description = '',
                user_id = '',
                infrastructure = 'AWS',
                last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                    gen_ai_enabled = True, ),
                client_id = '',
                client_secret = '',
        )
        """

    def testSensitiveDataPlane(self):
        """Test SensitiveDataPlane"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
